import { DocumentProps, PageProps } from 'react-pdf';

import { Awaited } from './utils/promise';

export * from 'react-pdf';

type PageCallback = Parameters<Exclude<PageProps['onRenderSuccess'], undefined>>[number];

export type PDFDocumentProxy = Parameters<Exclude<DocumentProps['onLoadSuccess'], undefined>>[number];

export type PageViewport = Pick<ReturnType<PageCallback['getViewport']>, 'width' | 'height'> & { rotate: number };

export interface TLTWH {
	left: number;
	top: number;
	width: number;
	height: number;
}

export type TNewHighlight = {
	position: TLTWH;
	pageNumber: number;
};

export type IHighlightType = 'table' | 'cell' | 'annotation' | 'page' | 'document' | 'form' | 'word';

export type THighlight = {
	id: string;
	selectedColor: string;
	selectedBorderColor?: string;
	type: IHighlightType;
	unselectedBorderColor?: string;
	unselectedColor?: string;
	label?: string;
	groupId?: string;
} & TNewHighlight;

export type THighlightItem<THT> = Omit<THT, 'position'> & { position: TLTWH };

export type THighLightItemProps = {
	onClick?: (itemId: string) => void;
	onDoubleClick?: (itemId: string) => void;
	onMouseOver?: () => void;
	onMouseOut?: () => void;
};

export interface SinglePdfRenderProps extends PageProps {
	highlights?: Array<THighlight>;
	highlightAreaProps?: THighLightItemProps;
	activeHighlightsId?: Array<string>;
	focusHighlightId?: string;
	showLabels?: boolean;
	className?: string;
	innerClassName?: string;
}

export interface PDFRenderRef {
	viewport: PageViewport;
	defaultRotate: number;
}

export type PDFPageProxy = Awaited<ReturnType<PDFDocumentProxy['getPage']>>;

export interface PDFUtilsType {
	percentageToViewport(ref: PDFRenderRef, data: TLTWH): TLTWH;
	viewportToPercentage(ref: PDFRenderRef, data: TLTWH): TLTWH;
}
